@@ -1,9 +1,12 @@
 """route factories."""
+import functools
+import inspect
 from typing import Any, Callable, Dict, List, Optional, Type, TypedDict, Union
 
 from fastapi import Depends, params
 from fastapi.dependencies.utils import get_parameterless_sub_dependant
 from pydantic import BaseModel
+from starlette.concurrency import run_in_threadpool
 from starlette.requests import Request
 from starlette.responses import JSONResponse, Response
 from starlette.routing import BaseRoute, Match
@@ -21,12 +24,28 @@ def _wrap_response(resp: Any, response_class: Type[Response]) -> Response:
         return Response(status_code=HTTP_204_NO_CONTENT)
 
 
+def sync_to_async(func):
+    """Run synchronous function asynchronously in a background thread."""
+
+    @functools.wraps(func)
+    async def run(*args, **kwargs):
+        return await run_in_threadpool(func, *args, **kwargs)
+
+    return run
+
+
 def create_async_endpoint(
     func: Callable,
     request_model: Union[Type[APIRequest], Type[BaseModel], Dict],
     response_class: Type[Response] = JSONResponse,
 ):
-    """Wrap a coroutine in another coroutine which may be used to create a FastAPI endpoint."""
+    """Wrap a function in a coroutine which may be used to create a FastAPI endpoint.
+
+    Synchronous functions are executed asynchronously using a background thread.
+    """
+    if not inspect.iscoroutinefunction(func):
+        func = sync_to_async(func)
+
     if issubclass(request_model, APIRequest):
 
         async def _endpoint(
@@ -63,44 +82,6 @@ def create_async_endpoint(
     return _endpoint
 
 
-def create_sync_endpoint(
-    func: Callable,
-    request_model: Union[Type[APIRequest], Type[BaseModel], Dict],
-    response_class: Type[Response] = JSONResponse,
-):
-    """Wrap a function in another function which may be used to create a FastAPI endpoint."""
-    if issubclass(request_model, APIRequest):
-
-        def _endpoint(
-            request: Request,
-            request_data: request_model = Depends(),  # type:ignore
-        ):
-            """Endpoint."""
-            return _wrap_response(
-                func(request=request, **request_data.kwargs()), response_class
-            )
-
-    elif issubclass(request_model, BaseModel):
-
-        def _endpoint(
-            request: Request,
-            request_data: request_model,  # type:ignore
-        ):
-            """Endpoint."""
-            return _wrap_response(func(request_data, request=request), response_class)
-
-    else:
-
-        def _endpoint(
-            request: Request,
-            request_data: Dict[str, Any],  # type:ignore
-        ):
-            """Endpoint."""
-            return _wrap_response(func(request_data, request=request), response_class)
-
-    return _endpoint
-
-
 class Scope(TypedDict, total=False):
     """More strict version of Starlette's Scope."""
 
